@@ -1,5 +1,5 @@
 package URI::Fast;
-$URI::Fast::VERSION = '0.20';
+$URI::Fast::VERSION = '0.21';
 # ABSTRACT: A fast(er) URI parser
 
 use utf8;
@@ -137,7 +137,7 @@ URI::Fast - A fast(er) URI parser
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -602,7 +602,7 @@ SV* decode(SV* in) {
 
   olen = uri_decode(src, ilen, dest);
   out  = newSVpv(dest, olen);
-  SvUTF8_on(out);
+  sv_utf8_decode(out);
 
   return out;
 }
@@ -813,7 +813,7 @@ SV* split_path(SV* uri) {
   while (idx < len) {
     brk = strcspn(&str[idx], "/");
     tmp = newSVpvn(&str[idx], brk);
-    SvUTF8_on(tmp);
+    sv_utf8_decode(tmp);
     av_push(arr, tmp);
     idx += brk + 1;
   }
@@ -876,7 +876,7 @@ SV* query_hash(SV* uri) {
 
       // Create new sv to store value
       tmp = newSVpv(val, vlen);
-      SvUTF8_on(tmp);
+      sv_utf8_decode(tmp);
     }
 
     // Move to next key
@@ -925,7 +925,7 @@ SV* get_param(SV* uri, SV* sv_key) {
       vlen = uri_decode(&src[idx], brk, val);
       idx += brk + 1;
       value = newSVpv(val, vlen);
-      SvUTF8_on(value);
+      sv_utf8_decode(value);
       av_push(out, value);
     }
     else {
